@@ -208,19 +208,19 @@
 # 3. broke out fingerprint distance
 # 4. Added optional passed in alphabet
 
-import selfies
+import selfies  # type: ignore
 import random
-from rdkit import Chem
-from rdkit.Chem import MolFromSmiles as smi2mol
-from rdkit.Chem import MolToSmiles as mol2smi
+from rdkit import Chem  # type: ignore
+from rdkit.Chem import MolFromSmiles as smi2mol  # type: ignore
+from rdkit.Chem import MolToSmiles as mol2smi  # type: ignore
 
-from rdkit.Chem import AllChem
-from rdkit.DataStructs.cDataStructs import TanimotoSimilarity
-from rdkit.Chem import Mol
-from rdkit.Chem.AtomPairs.Sheridan import GetBPFingerprint, GetBTFingerprint
-from rdkit.Chem.Pharm2D import Generate, Gobbi_Pharm2D
+from rdkit.Chem import AllChem  # type: ignore
+from rdkit.DataStructs.cDataStructs import TanimotoSimilarity  # type: ignore
+from rdkit.Chem import Mol  # type: ignore
+from rdkit.Chem.AtomPairs.Sheridan import GetBPFingerprint, GetBTFingerprint  # type: ignore
+from rdkit.Chem.Pharm2D import Generate, Gobbi_Pharm2D  # type: ignore
 
-from rdkit import RDLogger
+from rdkit import RDLogger  # type: ignore
 
 RDLogger.DisableLog("rdApp.*")
 
@@ -236,30 +236,29 @@ def randomize_smiles(mol):
     if not mol:
         return None
 
-    Chem.Kekulize(mol)
     return mol2smi(
-        mol, canonical=False, doRandom=True, isomericSmiles=False, kekuleSmiles=True
+        mol, canonical=False, doRandom=True, isomericSmiles=True, kekuleSmiles=True
     )
 
 
-def sanitize_smiles(smi):
+def sanitize_smiles(smi, canonical=False):
     """Return a canonical smile representation of smi
 
     Parameters:
-    smi (string) : smile string to be canonicalized
+    smi (string) : smile string to be sanitized
+    canonical (bool) : whether or note to also canonicalize
 
     Returns:
     mol (rdkit.Chem.rdchem.Mol) : RdKit mol object                          (None if invalid smile string smi)
-    smi_canon (string)          : Canonicalized smile representation of smi (None if invalid smile string smi)
+    smi (string)          : Possibly canonical SMILES representation of smi (None if invalid smile string smi)
     conversion_successful (bool): True/False to indicate if conversion was  successful
     """
     try:
         mol = smi2mol(smi, sanitize=True)
-        smi_canon = mol2smi(mol, isomericSmiles=False, canonical=True)
-        check = smi2mol(smi_canon)
-        if check is None:
+        smi = mol2smi(mol, canonical=canonical, kekuleSmiles=True)
+        if mol is None:
             return None, None, False
-        return (mol, smi_canon, True)
+        return (mol, smi, True)
     except Exception as e:
         return (None, None, False)
 
@@ -358,7 +357,6 @@ def mutate_selfie(selfie, max_molecules_len, alphabet, write_fail_cases=False):
 
     Returns:
     selfie_mutated    (string)  : Mutated SELFIE string
-    smiles_canon      (string)  : canonical smile of mutated SELFIE string
     """
     valid = False
     fail_counter = 0
@@ -413,15 +411,15 @@ def mutate_selfie(selfie, max_molecules_len, alphabet, write_fail_cases=False):
         sf = "".join(x for x in chars_selfie)
 
         smiles = selfies.decoder(selfie_mutated)
-        mol, smiles_canon, done = sanitize_smiles(smiles)
-        if len(selfie_mutated_chars) > max_molecules_len or smiles_canon == "":
+        _, smiles, done = sanitize_smiles(smiles)
+        if len(selfie_mutated_chars) > max_molecules_len or smiles == "":
             done = False
         if done:
             valid = True
         else:
             valid = False
 
-    return (selfie_mutated, smiles_canon)
+    return selfie_mutated
 
 
 def get_mutated_SELFIES(selfies_ls, num_mutations, alphabet):
@@ -442,9 +440,7 @@ def get_mutated_SELFIES(selfies_ls, num_mutations, alphabet):
             str_chars = get_selfie_chars(str_)
             max_molecules_len = len(str_chars) + num_mutations
 
-            selfie_mutated, smiles_canon = mutate_selfie(
-                str_, max_molecules_len, alphabet
-            )
+            selfie_mutated = mutate_selfie(str_, max_molecules_len, alphabet)
             selfie_ls_mut_ls.append(selfie_mutated)
 
         selfies_ls = selfie_ls_mut_ls.copy()
